diff scripts/ode/private/ode_event_handler.m @ 30893:e1788b1a315f

maint: Use "fcn" as preferred abbreviation for "function" in m-files. * accumarray.m, accumdim.m, quadl.m, quadv.m, randi.m, structfun.m, __is_function__.m, uigetfile.m, uimenu.m, uiputfile.m, doc_cache_create.m, colorspace_conversion_input_check.m, imageIO.m, argnames.m, vectorize.m, vectorize.m, normest1.m, inputname.m, nthargout.m, display_info_file.m, decic.m, ode15i.m, ode15s.m, ode23.m, ode23s.m, ode45.m, odeset.m, check_default_input.m, integrate_adaptive.m, ode_event_handler.m, runge_kutta_23.m, runge_kutta_23s.m, runge_kutta_45_dorpri.m, runge_kutta_interpolate.m, starting_stepsize.m, __all_opts__.m, fminbnd.m, fminsearch.m, fminunc.m, fsolve.m, fzero.m, sqp.m, fplot.m, plotyy.m, __bar__.m, __ezplot__.m, flat_entry.html, profexport.m, movfun.m, bicg.m, bicgstab.m, cgs.m, eigs.m, gmres.m, pcg.m, __alltohandles__.m, __sprand__.m, qmr.m, tfqmr.m, dump_demos.m: Replace "func", "fun", "fn" in documentation and variable names with "fcn".
author Rik <rik@octave.org>
date Mon, 04 Apr 2022 18:14:56 -0700
parents 796f54d4ddbf
children 449ed6f427cb
line wrap: on
line diff
--- a/scripts/ode/private/ode_event_handler.m	Mon Apr 04 11:22:26 2022 -0700
+++ b/scripts/ode/private/ode_event_handler.m	Mon Apr 04 18:14:56 2022 -0700
@@ -24,9 +24,9 @@
 ########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn {} {@var{retval} =} ode_event_handler (@var{@@evtfun}, @var{t}, @var{y}, @var{flag}, @var{par1}, @var{par2}, @dots{})
+## @deftypefn {} {@var{retval} =} ode_event_handler (@var{@@evtfcn}, @var{t}, @var{y}, @var{flag}, @var{par1}, @var{par2}, @dots{})
 ##
 ## Return the solution of the event function (@var{@@evtfun}) which is
 ## specified in the form of a function handle.
 ##
 ## The second input argument @var{t} is a scalar double and specifies the time
@@ -60,7 +60,7 @@
 ## necessary to call it directly.
 ## @end deftypefn
 
-function retval = ode_event_handler (evtfun, t, y, flag = "", varargin)
+function retval = ode_event_handler (evtfcn, t, y, flag = "", varargin)
 
   ## No error handling has been implemented in this function to achieve
   ## the highest performance possible.
@@ -85,9 +85,9 @@
     ## Process the event, i.e.,
     ## find the zero crossings for either a rising or falling edge
     if (! iscell (y))
-      inpargs = {evtfun, t, y};
+      inpargs = {evtfcn, t, y};
     else
-      inpargs = {evtfun, t, y{1}, y{2}};
+      inpargs = {evtfcn, t, y{1}, y{2}};
       y = y{1};  # Delete cell element 2
     endif
     if (nargin > 4)
@@ -141,9 +141,9 @@
     firstrun = true;
 
     if (! iscell (y))
-      inpargs = {evtfun, t, y};
+      inpargs = {evtfcn, t, y};
     else
-      inpargs = {evtfun, t, y{1}, y{2}};
+      inpargs = {evtfcn, t, y{1}, y{2}};
       y = y{1};  # Delete cell element 2
     endif
     if (nargin > 4)
@@ -24,9 +24,9 @@
 ##
-## Return the solution of the event function (@var{@@evtfun}) which is
+## Return the solution of the event function (@var{@@evtfcn}) which is
 ## specified in the form of a function handle.
 ##